@@ -38,7 +38,7 @@ class Game(GObject.Object):
         "game-started": (GObject.SIGNAL_RUN_FIRST, None, ()),
         "game-stop": (GObject.SIGNAL_RUN_FIRST, None, ()),
         "game-stopped": (GObject.SIGNAL_RUN_FIRST, None, (int,)),
-        "game-removed": (GObject.SIGNAL_RUN_FIRST, None, (int,)),
+        "game-removed": (GObject.SIGNAL_RUN_FIRST, None, ()),
         "game-updated": (GObject.SIGNAL_RUN_FIRST, None, ()),
     }
 
@@ -56,7 +56,7 @@ class Game(GObject.Object):
         self.name = game_data.get("name") or ""
 
         self.game_config_id = game_data.get("configpath") or ""
-        self.is_installed = bool(game_data.get("installed")) and self.game_config_id
+        self.is_installed = bool(game_data.get("installed") and self.game_config_id)
         self.platform = game_data.get("platform") or ""
         self.year = game_data.get("year") or ""
         self.lastplayed = game_data.get("lastplayed") or 0
@@ -67,6 +67,7 @@ class Game(GObject.Object):
             self.playtime = float(game_data.get("playtime") or 0.0)
         except ValueError:
             logger.error("Invalid playtime value %s", game_data.get("playtime"))
+            self.playtime = 0.0
 
         if self.game_config_id:
             self.load_config()
@@ -82,11 +83,19 @@ class Game(GObject.Object):
         self.compositor_disabled = False
         self.stop_compositor = self.start_compositor = ""
         self.original_outputs = None
-        self.log_buffer = Gtk.TextBuffer()
-        self.log_buffer.create_tag("warning", foreground="red")
-
+        self._log_buffer = None
         self.timer = Timer()
 
+    @property
+    def log_buffer(self):
+        if self._log_buffer is None:
+            self._log_buffer = Gtk.TextBuffer()
+            self._log_buffer.create_tag("warning", foreground="red")
+            if self.game_thread:
+                self.game_thread.set_log_buffer(self._log_buffer)
+                self._log_buffer.set_text(self.game_thread.stdout)
+        return self._log_buffer
+
     def __repr__(self):
         return self.__unicode__()
 
@@ -181,12 +190,14 @@ class Game(GObject.Object):
         if self.config:
             self.config.remove()
         xdgshortcuts.remove_launcher(self.slug, self.id, desktop=True, menu=True)
-        self.emit("game-removed", self.id)
+        self.is_installed = False
+        self.emit("game-removed")
         return from_library
 
     def set_platform_from_runner(self):
         """Set the game's platform from the runner"""
         if not self.runner:
+            logger.warning("Game has no runner, can't set platform")
             return
         self.platform = self.runner.get_platform()
         if not self.platform:
@@ -201,6 +212,7 @@ class Game(GObject.Object):
         logger.debug("Saving %s", self)
         if not metadata_only:
             self.config.save()
+        self.set_platform_from_runner()
         self.id = pga.add_or_update(
             name=self.name,
             runner=self.runner_name,
@@ -215,6 +227,7 @@ class Game(GObject.Object):
             id=self.id,
             playtime=self.playtime,
         )
+        self.emit("game-updated")
 
     def prelaunch(self):
         """Verify that the current game can be launched."""
@@ -352,6 +365,8 @@ class Game(GObject.Object):
             launch_arguments.insert(0, "virtualgl")
             launch_arguments.insert(0, "-b")
             launch_arguments.insert(0, "optirun")
+        elif optimus == "pvkrun" and system.find_executable("pvkrun"):
+            launch_arguments.insert(0, "pvkrun")
 
         xephyr = system_config.get("xephyr") or "off"
         if xephyr != "off":
@@ -494,7 +509,7 @@ class Game(GObject.Object):
             runner=self.runner,
             env=self.game_runtime_config["env"],
             term=self.game_runtime_config["terminal"],
-            log_buffer=self.log_buffer,
+            log_buffer=self._log_buffer,
             include_processes=self.game_runtime_config["include_processes"],
             exclude_processes=self.game_runtime_config["exclude_processes"],
         )
@@ -529,11 +544,20 @@ class Game(GObject.Object):
         self.xboxdrv_thread.start()
 
     @staticmethod
-    def xboxdrv_stop():
-        os.system("pkexec xboxdrvctl --shutdown")
+    def reload_xpad():
+        """Reloads the xpads module.
+        The path is hardcoded because this script is allowed to be executed as
+        root with a PolicyKit rule put in place by the packages.
+        Note to packagers: If you don't intend to create a PolicyKit rule for
+        this script then don't package it as calling it will fail.
+        """
         if system.path_exists("/usr/share/lutris/bin/resetxpad"):
             os.system("pkexec /usr/share/lutris/bin/resetxpad")
 
+    def xboxdrv_stop(self):
+        os.system("pkexec xboxdrvctl --shutdown")
+        self.reload_xpad()
+
     def prelaunch_beat(self):
         """Watch the prelaunch command"""
         if self.prelaunch_executor.is_running:
