@@ -18,6 +18,7 @@ class Dialog(Gtk.Dialog):
     def __init__(self, title=None, parent=None, flags=0, buttons=None):
         super().__init__(title, parent, flags, buttons)
         self.set_border_width(10)
+        self.connect("delete-event", lambda *x: x[0].destroy())
         self.set_destroy_with_parent(True)
 
 
@@ -465,7 +466,7 @@ class WineNotInstalledWarning(DontShowAgainDialog):
             secondary_message="Having Wine installed on your system guarantees that "
             "Wine builds from Lutris will have all required dependencies.\n\nPlease "
             "follow the instructions given in the <a "
-            "href='https://github.com/lutris/lutris/wiki/Wine'>Lutris Wiki</a> to "
+            "href='https://github.com/lutris/lutris/wiki/Wine-Dependencies'>Lutris Wiki</a> to "
             "install Wine.",
             parent=parent,
         )
