@@ -40,6 +40,10 @@ class InstallerWindow(Gtk.ApplicationWindow):
         Gtk.ApplicationWindow.__init__(self, icon_name="lutris", application=application)
         self.application = application
         self.set_show_menubar(False)
+        self.set_size_request(420, 420)
+        self.set_default_size(600, 480)
+        self.set_position(Gtk.WindowPosition.CENTER)
+
         self.interpreter = None
         self.selected_directory = None  # Latest directory chosen by user
         self.parent = parent
@@ -50,11 +54,6 @@ class InstallerWindow(Gtk.ApplicationWindow):
         self.log_buffer = None
         self.log_textview = None
 
-        # Dialog properties
-        self.set_size_request(420, 420)
-        self.set_default_size(600, 480)
-        self.set_position(Gtk.WindowPosition.CENTER)
-
         self.vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=12)
         self.vbox.set_margin_top(18)
         self.vbox.set_margin_bottom(18)
@@ -341,7 +340,7 @@ class InstallerWindow(Gtk.ApplicationWindow):
 
         if self.location_entry:
             self.location_entry.destroy()
-        self.location_entry = FileChooserEntry(title, action, default_path)
+        self.location_entry = FileChooserEntry(title, action, path=default_path)
         self.location_entry.show_all()
         if callback_on_changed:
             self.location_entry.entry.connect("changed", callback_on_changed, action)
@@ -464,8 +463,6 @@ class InstallerWindow(Gtk.ApplicationWindow):
     # ----------------
 
     def on_install_finished(self):
-        """Actual game installation."""
-        self.notify_install_success()
         self.clean_widgets()
 
         # Shortcut checkboxes
@@ -495,16 +492,6 @@ class InstallerWindow(Gtk.ApplicationWindow):
             self.set_urgency_hint(True)  # Blink in taskbar
             self.connect("focus-in-event", self.on_window_focus)
 
-    def notify_install_success(self, game_id=None):
-
-        # Nothing to notify in case of extends scripts
-        if self.interpreter.extends:
-            return
-
-        game_id = game_id or self.interpreter.game_id
-        if self.parent:
-            self.parent.view.emit("game-installed", game_id)
-
     def on_window_focus(self, widget, *args):
         self.set_urgency_hint(False)
 
