@@ -5,13 +5,14 @@ import stat
 import shutil
 import shlex
 import json
+import glob
 
 from gi.repository import GLib
 
 from lutris.installer.errors import ScriptingError
 
 from lutris import runtime
-from lutris import settings
+from lutris.cache import get_cache_path
 from lutris.util import extract, disks, system
 from lutris.util.fileio import EvilConfigParser, MultiOrderedDict
 from lutris.util.log import logger
@@ -66,7 +67,7 @@ class CommandsMixin:
 
     def _is_cached_file(self, file_path):
         """Return whether a file referenced by file_id is stored in the cache"""
-        pga_cache_path = settings.read_setting("pga_cache_path")
+        pga_cache_path = get_cache_path()
         if not pga_cache_path:
             return False
         return file_path.startswith(pga_cache_path)
@@ -153,24 +154,26 @@ class CommandsMixin:
         """Extract a file, guessing the compression method."""
         self._check_required_params([("file", "src")], data, "extract")
         src_param = data.get("file") or data.get("src")
-        filename = self._get_file(src_param)
+        filespec = self._get_file(src_param)
 
-        if not os.path.exists(filename):
-            raise ScriptingError("%s does not exists" % filename)
+        filenames = glob.glob(filespec)
+
+        if not filenames:
+            raise ScriptingError("%s does not exist" % filespec)
         if "dst" in data:
             dest_path = self._substitute(data["dst"])
         else:
             dest_path = self.target_path
-        msg = "Extracting %s" % os.path.basename(filename)
-        logger.debug(msg)
-        GLib.idle_add(self.parent.set_status, msg)
-        merge_single = "nomerge" not in data
-        extractor = data.get("format")
-        logger.debug("extracting file %s to %s", filename, dest_path)
-
-        self._killable_process(
-            extract.extract_archive, filename, dest_path, merge_single, extractor
-        )
+        for filename in filenames:
+            msg = "Extracting %s" % os.path.basename(filename)
+            logger.debug(msg)
+            GLib.idle_add(self.parent.set_status, msg)
+            merge_single = "nomerge" not in data
+            extractor = data.get("format")
+            logger.debug("extracting file %s to %s", filename, dest_path)
+            self._killable_process(
+                extract.extract_archive, filename, dest_path, merge_single, extractor
+            )
 
     def input_menu(self, data):
         """Display an input request as a dropdown menu with options."""
