@@ -18,7 +18,6 @@ from lutris.util.wine.prefix import WinePrefixManager
 from lutris.util.wine.x360ce import X360ce
 from lutris.util.wine import dxvk
 from lutris.util.wine.wine import (
-    PROTON_PATH,
     POL_PATH,
     WINE_DIR,
     WINE_PATHS,
@@ -28,6 +27,7 @@ from lutris.util.wine.wine import (
     esync_display_version_warning,
     get_default_version,
     get_overrides_env,
+    get_proton_paths,
     get_real_executable,
     get_system_wine_version,
     get_wine_versions,
@@ -124,14 +124,6 @@ class wine(Runner):
     def __init__(self, config=None):
         super(wine, self).__init__(config)
         self.dll_overrides = {}
-        self.context_menu_entries = [
-            ("wineexec", "Run EXE inside wine prefix", self.run_wineexec),
-            ("winecfg", "Wine configuration", self.run_winecfg),
-            ("wine-regedit", "Wine registry", self.run_regedit),
-            ("winekill", "Kill all wine processes", self.run_winekill),
-            ("winetricks", "Winetricks", self.run_winetricks),
-            ("joycpl", "Joystick Control Panel", self.run_joycpl),
-        ]
 
         def get_wine_version_choices():
             version_choices = [("Custom (select executable below)", "custom")]
@@ -444,6 +436,21 @@ class wine(Runner):
             },
         ]
 
+    @property
+    def context_menu_entries(self):
+        menu_entries = [
+            ("wineexec", "Run EXE inside wine prefix", self.run_wineexec)
+        ]
+        if "Proton" not in self.get_version():
+            menu_entries.append(("winecfg", "Wine configuration", self.run_winecfg))
+        menu_entries += [
+            ("wine-regedit", "Wine registry", self.run_regedit),
+            ("winekill", "Kill all wine processes", self.run_winekill),
+            ("winetricks", "Winetricks", self.run_winetricks),
+            ("joycpl", "Joystick Control Panel", self.run_joycpl),
+        ]
+        return menu_entries
+
     @property
     def prefix_path(self):
         prefix_path = self.game_config.get("prefix")
@@ -493,10 +500,13 @@ class wine(Runner):
             return get_default_version()
 
     def get_path_for_version(self, version):
+        # logger.debug("Getting path for Wine %s", version)
         if version in WINE_PATHS.keys():
             return system.find_executable(WINE_PATHS[version])
         if "Proton" in version:
-            return os.path.join(PROTON_PATH, version, "dist/bin/wine")
+            for proton_path in get_proton_paths():
+                if os.path.isfile(os.path.join(proton_path, version, "dist/bin/wine")):
+                    return os.path.join(proton_path, version, "dist/bin/wine")
         if version.startswith("PlayOnLinux"):
             version, arch = version.split()[1].rsplit("-", 1)
             return os.path.join(POL_PATH, "wine", "linux-" + arch, version, "bin/wine")
@@ -624,8 +634,7 @@ class wine(Runner):
 
     def set_regedit_keys(self):
         """Reset regedit keys according to config."""
-        prefix = self.prefix_path
-        prefix_manager = WinePrefixManager(prefix)
+        prefix_manager = WinePrefixManager(self.prefix_path)
         # Those options are directly changed with the prefix manager and skip
         # any calls to regedit.
         managed_keys = {
@@ -728,10 +737,12 @@ class wine(Runner):
     def get_runtime_env(self):
         """Return runtime environment variables with path to wine for Lutris builds"""
         wine_path = self.get_executable()
-        if WINE_DIR or PROTON_PATH in wine_path:
+        wine_root = None
+        if WINE_DIR:
             wine_root = os.path.dirname(os.path.dirname(wine_path))
-        else:
-            wine_root = None
+        for proton_path in get_proton_paths():
+            if proton_path in wine_path:
+                wine_root = os.path.dirname(os.path.dirname(wine_path))
         if "-4." in wine_path or "/4." in wine_path:
             version = "Ubuntu-18.04"
         else:
