@@ -9,10 +9,12 @@ from lutris.util.system import create_folder
 from lutris.util.graphics import drivers
 from lutris.util.graphics import vkquery
 from lutris.util.linux import LINUX_SYSTEM
+from lutris.gui.widgets.utils import open_uri
+from lutris.gui.dialogs import DontShowAgainDialog
 
 
-def check_config():
-    """Check if initial configuration is correct."""
+def init_dirs():
+    """Creates Lutris directories"""
     directories = [
         settings.CONFIG_DIR,
         os.path.join(settings.CONFIG_DIR, "runners"),
@@ -32,11 +34,21 @@ def check_config():
     for directory in directories:
         create_folder(directory)
 
+
+def init_db():
+    """Initialize the SQLite DB"""
     pga.syncdb()
 
 
+def init_lutris():
+    """Run full initialization of Lutris"""
+    init_dirs()
+    init_db()
+
+
 def check_driver():
     """Report on the currently running driver"""
+    driver_info = {}
     if drivers.is_nvidia():
         driver_info = drivers.get_nvidia_driver_info()
         # pylint: disable=logging-format-interpolation
@@ -58,11 +70,28 @@ def check_driver():
 
     for card in drivers.get_gpus():
         # pylint: disable=logging-format-interpolation
-        logger.info(
-            "GPU: {PCI_ID} {PCI_SUBSYS_ID} using {DRIVER} drivers".format(
-                **drivers.get_gpu_info(card)
+        try:
+            logger.info(
+                "GPU: {PCI_ID} {PCI_SUBSYS_ID} using {DRIVER} drivers".format(
+                    **drivers.get_gpu_info(card)
+                )
+            )
+        except KeyError:
+            logger.error("Unable to get GPU information from '%s'", card)
+
+    if drivers.is_outdated():
+        setting = "hide-outdated-nvidia-driver-warning"
+        if settings.read_setting(setting) != "True":
+            DontShowAgainDialog(
+                setting,
+                "Your Nvidia driver is outdated.",
+                secondary_message="You are currently running driver %s which does not "
+                "fully support all features for Vulkan and DXVK games.\n"
+                "Please upgrade your driver as described in our "
+                "<a href='https://github.com/lutris/lutris/wiki/Installing-drivers'>"
+                "installation guide</a>"
+                % driver_info["nvrm"]["version"]
             )
-        )
 
 
 def check_libs(all_components=False):
@@ -86,6 +115,23 @@ def check_vulkan():
         logger.info("Vulkan is not available or your system isn't Vulkan capable")
 
 
+def check_donate():
+    setting = "dont-support-lutris"
+    if settings.read_setting(setting) != "True":
+        open_uri("https://lutris.net/donate")
+        DontShowAgainDialog(
+            setting,
+            "Please support Lutris!",
+            secondary_message="Lutris is entirely funded by its community and will "
+            "remain an independent gaming platform.\n"
+            "For Lutris to survive and grow, the project needs your help.\n"
+            "Please consider making a donation if you can. This will greatly help "
+            "cover the costs of hosting the project and fund new features "
+            "like cloud saves or a full-screen interface for the TV!\n"
+            "<a href='https://lutris.net/donate'>SUPPORT US! https://lutris.net/donate</a>"
+        )
+
+
 def fill_missing_platforms():
     """Sets the platform on games where it's missing.
     This should never happen.
@@ -97,13 +143,14 @@ def fill_missing_platforms():
         game = Game(game_id=pga_game["id"])
         logger.error("Providing missing platorm for game %s", game.slug)
         game.set_platform_from_runner()
-        game.save(metadata_only=True)
+        if game.platform:
+            game.save(metadata_only=True)
 
 
 def run_all_checks():
     """Run all startup checks"""
-    check_config()
     check_driver()
     check_libs()
     check_vulkan()
+    check_donate()
     fill_missing_platforms()
