@@ -4,13 +4,14 @@ import configparser
 
 class SettingsIO:
     """ConfigParser abstraction."""
+
     def __init__(self, config_file):
         self.config_file = config_file
         self.config = configparser.ConfigParser()
         if os.path.exists(self.config_file):
             self.config.read([self.config_file])
 
-    def read_setting(self, key, section='lutris', default=None):
+    def read_setting(self, key, section="lutris", default=None):
         """Read a setting from the config file
 
         Params:
@@ -23,10 +24,10 @@ class SettingsIO:
         except (configparser.NoOptionError, configparser.NoSectionError):
             return default
 
-    def write_setting(self, key, value, section='lutris'):
+    def write_setting(self, key, value, section="lutris"):
         if not self.config.has_section(section):
             self.config.add_section(section)
         self.config.set(section, key, str(value))
 
-        with open(self.config_file, 'w') as config_file:
+        with open(self.config_file, "w") as config_file:
             self.config.write(config_file)
